package com.sun.corba.se.impl.transport;

import com.sun.corba.se.impl.orbutil.ORBUtility;
import org.omg.CORBA.INTERNAL;
import com.sun.corba.se.spi.orbutil.threadpool.NoSuchWorkQueueException;
import com.sun.corba.se.spi.orbutil.threadpool.NoSuchThreadPoolException;
import java.nio.channels.SelectionKey;
import com.sun.corba.se.spi.orbutil.threadpool.Work;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.pept.transport.EventHandler;

public abstract class EventHandlerBase implements EventHandler
{
    protected ORB orb;
    protected Work work;
    protected boolean useWorkerThreadForEvent;
    protected boolean useSelectThreadToWait;
    protected SelectionKey selectionKey;
    
    public EventHandlerBase() {
    }
    
    public void setUseSelectThreadToWait(boolean useSelectThreadToWait) {
        this.useSelectThreadToWait = useSelectThreadToWait;
    }
    
    public boolean shouldUseSelectThreadToWait() {
        return this.useSelectThreadToWait;
    }
    
    public void setSelectionKey(SelectionKey selectionKey) {
        this.selectionKey = selectionKey;
    }
    
    public SelectionKey getSelectionKey() {
        return this.selectionKey;
    }
    
    public void handleEvent() {
        if (this.orb.transportDebugFlag) {
            this.dprint(".handleEvent->: " + this);
        }
        this.getSelectionKey().interestOps(this.getSelectionKey().interestOps() & ~this.getInterestOps());
        if (this.shouldUseWorkerThreadForEvent()) {
            Object obj = null;
            try {
                if (this.orb.transportDebugFlag) {
                    this.dprint(".handleEvent: addWork to pool: 0");
                }
                this.orb.getThreadPoolManager().getThreadPool(0).getWorkQueue(0).addWork(this.getWork());
            }
            catch (NoSuchThreadPoolException ex) {
                obj = ex;
            }
            catch (NoSuchWorkQueueException ex2) {
                obj = ex2;
            }
            if (obj != null) {
                if (this.orb.transportDebugFlag) {
                    this.dprint(".handleEvent: " + obj);
                }
                INTERNAL o = new INTERNAL("NoSuchThreadPoolException");
                o.initCause(obj);
                throw o;
            }
        }
        else {
            if (this.orb.transportDebugFlag) {
                this.dprint(".handleEvent: doWork");
            }
            this.getWork().doWork();
        }
        if (this.orb.transportDebugFlag) {
            this.dprint(".handleEvent<-: " + this);
        }
    }
    
    public boolean shouldUseWorkerThreadForEvent() {
        return this.useWorkerThreadForEvent;
    }
    
    public void setUseWorkerThreadForEvent(boolean useWorkerThreadForEvent) {
        this.useWorkerThreadForEvent = useWorkerThreadForEvent;
    }
    
    public void setWork(Work work) {
        this.work = work;
    }
    
    public Work getWork() {
        return this.work;
    }
    
    private void dprint(String s) {
        ORBUtility.dprint("EventHandlerBase", s);
    }
}
